@@ -16,9 +16,11 @@
 
 import pynag.Model
 from pynag.Model import ObjectDefinition
+import os
+import os.path
 
 # cfg_file is where our main nagios config file is
-pynag.Model.cfg_file = '/etc/nagios/nagios.cfg'
+pynag.Model.cfg_file = '/etc/nagios3/nagios.cfg'
 
 # pynag_directory is where the new objects will be saved
 pynag.Model.pynag_directory = '/tmp/nagios/conf.d'
@@ -31,12 +33,18 @@ for i in all_objects:
     print "Saving", i.object_type, i.get_description(), "...",
     # Set a new filename for our object, None means
     # That pynag decides where it goes
-    new_filename = None
+    new_filename = i.get_suggested_filename()
+    print new_filename
+    continue
     # Alternative:
     # if i.object.type == 'host' and i.host_name is not None:
     #     new_filename = '/tmp/nagios/conf.d/hosts/%s" % i.host_name
     
-    i.set_filename(new_filename)
-    i.save()
-    print "Saved to", i.get_filename()
+    dirname = os.path.dirname(new_filename)
+    if not os.path.exists(dirname):
+        os.makedirs(dirname)
+    with open(new_filename, 'a') as f:
+        data = "\n" + str(i)
+        f.write(data)
+    print  new_filename
 
