@@ -34,9 +34,11 @@ from getpass import getuser
 import datetime
 import pynag.Plugins
 import sys
+from pynag.Utils.checkresult import CheckResult
 
 rlock = threading.RLock()
 
+
 class PynagError(Exception):
 
     """ The default pynag exception.
@@ -57,17 +59,20 @@ class PynagError(Exception):
 
 
 def runCommand(command, raise_error_on_fail=False, shell=True, env=None):
-    """ 
-    Run command from the shell prompt. Wrapper around subprocess.
+    """ Run command from the shell prompt. Wrapper around subprocess.
+
+    Args:
 
-    Arguments:
         command (str): string containing the command line to run
+
         raise_error_on_fail (bool): Raise PynagError if returncode > 0
 
     Returns:
-        string: stdout/stderr of the command run
+
+        str: stdout/stderr of the command run
 
     Raises:
+
         PynagError if returncode > 0
     """
     run_env = environ.copy()
@@ -81,7 +86,7 @@ def runCommand(command, raise_error_on_fail=False, shell=True, env=None):
                             env=run_env)
     stdout, stderr = proc.communicate('through stdin to stdout')
     result = proc.returncode, stdout, stderr
-    if proc.returncode > 0 and raise_error_on_fail == True:
+    if proc.returncode > 0 and raise_error_on_fail:
         error_string = "* Could not run command (return code= %s)\n" % proc.returncode
         error_string += "* Error was:\n%s\n" % (stderr.strip())
         error_string += "* Command was:\n%s\n" % command
@@ -97,10 +102,9 @@ def runCommand(command, raise_error_on_fail=False, shell=True, env=None):
 class GitRepo(object):
 
     def __init__(self, directory, auto_init=True, author_name="Pynag User", author_email=None):
-        """
-        Python Wrapper around Git command line.
+        """ Python Wrapper around Git command line.
 
-        Arguments:
+        Args:
 
             Directory (str): Path to the directory does the git repo reside in (i.e. '/etc/nagios')
 
@@ -142,8 +146,7 @@ class GitRepo(object):
         self._is_dirty = self.is_dirty  # Backwards compatibility
 
     def _update_author(self):
-        """ 
-        Updates environment variables GIT_AUTHOR_NAME and EMAIL
+        """ Updates environment variables GIT_AUTHOR_NAME and EMAIL
 
         Returns:
             None
@@ -152,10 +155,9 @@ class GitRepo(object):
         environ['GIT_AUTHOR_EMAIL'] = self.author_email.strip('<').strip('>')
 
     def _run_command(self, command):
-        """ 
-        Run a specified command from the command line. Return stdout 
-        
-        Arguments:
+        """ Run a specified command from the command line. Return stdout
+
+        Args:
             command (str): command to execute
 
         Returns:
@@ -164,22 +166,20 @@ class GitRepo(object):
         import subprocess
         import os
         cwd = self.directory
-        proc = subprocess.Popen(command, cwd=cwd, shell=True, stdout=subprocess.PIPE,stderr=subprocess.PIPE,)
+        proc = subprocess.Popen(command, cwd=cwd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE,)
         stdout, stderr = proc.communicate('through stdin to stdout')
         returncode = proc.returncode
-        if returncode > 0 and self.ignore_errors == False:
+        if returncode > 0 and self.ignore_errors is False:
             errorstring = "Command '%s' returned exit status %s.\n stdout: %s \n stderr: %s\n Current user: %s"
-            errorstring = errorstring % (command, returncode, stdout, stderr,getuser())
-            raise PynagError( errorstring, errorcode=returncode, errorstring=stderr )
+            errorstring = errorstring % (command, returncode, stdout, stderr, getuser())
+            raise PynagError(errorstring, errorcode=returncode, errorstring=stderr)
         return stdout
 
     def is_up_to_date(self):
-        """ 
-        Returns True if all files in git repo are fully commited 
-        
+        """ Returns True if all files in git repo are fully commited
+
         Returns:
             bool. Git repo is up-to-date
-
                 True -- All files are commited
 
                 False -- At least one file is not commited
@@ -187,8 +187,7 @@ class GitRepo(object):
         return len(self.get_uncommited_files()) == 0
 
     def get_valid_commits(self):
-        """ 
-        Returns a list of all commit ids from git log
+        """ Returns a list of all commit ids from git log
 
         Returns:
             List of all valid commit hashes
@@ -196,9 +195,8 @@ class GitRepo(object):
         return map(lambda x: x.get('hash'), self.log())
 
     def get_uncommited_files(self):
-        """ 
-        Returns a list of files that are have unstaged changes 
-        
+        """ Returns a list of files that are have unstaged changes
+
         Returns:
             List. All files that have unstaged changes.
         """
@@ -228,7 +226,7 @@ class GitRepo(object):
 
         Any arguments provided will be passed directly to pynag.Utils.grep() to filter the results.
 
-        Arguments:
+        Args:
             kwargs: Arguments passed to pynag.Utils.grep()
 
         Returns:
@@ -236,12 +234,13 @@ class GitRepo(object):
 
         Examples:
           self.log(author_name='nagiosadmin')
+
           self.log(comment__contains='localhost')
         """
         raw_log = self._run_command("git log --pretty='%H\t%an\t%ae\t%at\t%s'")
         result = []
         for line in raw_log.splitlines():
-            hash,author, authoremail, authortime, comment = line.split("\t", 4)
+            hash, author, authoremail, authortime, comment = line.split("\t", 4)
             result.append({
                 "hash": hash,
                 "author_name": author,
@@ -253,12 +252,11 @@ class GitRepo(object):
         return grep(result, **kwargs)
 
     def diff(self, commit_id_or_filename=None):
-        """ 
-        Returns diff (as outputted by "git diff") for filename or commit id.
+        """ Returns diff (as outputted by "git diff") for filename or commit id.
 
         If commit_id_or_filename is not specified. show diff against all uncommited files.
 
-        Arguments:
+        Args:
             commit_id_or_filename (str): git commit id or file to diff with
 
         Returns:
@@ -276,21 +274,20 @@ class GitRepo(object):
             commit_id_or_filename = commit_id_or_filename.replace("'", r"\'")
             command = "git diff '%s'" % commit_id_or_filename
         else:
-            raise  PynagError("%s is not a valid commit id or filename" % commit_id_or_filename)
+            raise PynagError("%s is not a valid commit id or filename" % commit_id_or_filename)
         # Clean single quotes from parameters:
         return self._run_command(command)
 
     def show(self, commit_id,):
-        """ 
-        Returns output from "git show" for a specified commit_id
+        """ Returns output from "git show" for a specified commit_id
 
-        Arguments:
+        Args:
             commit_id (str): Commit id of the commit to display (``git show``)
 
         Returns:
             str. Output of ``git show commit_id``
 
-        Raises: 
+        Raises:
             PynagError: Invalid commit_id was given
         """
         if commit_id not in self.get_valid_commits():
@@ -320,12 +317,12 @@ class GitRepo(object):
         return self.commit(message=message, filelist=filelist)
 
     def pre_save(self, object_definition, message):
-        """ 
-        Commits object_definition.get_filename() if it has any changes. This
-        function is called by :py:class:`pynag.Model.EventHandlers` before
+        """ Commits object_definition.get_filename() if it has any changes.
+
+        This function is called by :py:class:`pynag.Model.EventHandlers` before
         calling :py:meth:`pynag.Utils.GitRepo.save`
-        
-        Arguments:
+
+        Args:
 
             object_definition (pynag.Model.ObjectDefinition): object to commit changes
 
@@ -344,11 +341,10 @@ class GitRepo(object):
                             (object_definition.object_type, object_definition.get_shortname()))
 
     def save(self, object_definition, message):
-        """
-        Commits object_definition.get_filename() if it has any changes. This
-        function is called by :py:class:`pynag.Model.EventHandlers`
+        """ Commits object_definition.get_filename() if it has any changes.
+        This function is called by :py:class:`pynag.Model.EventHandlers`
 
-        Arguments:
+        Args:
 
             object_definition (pynag.Model.ObjectDefinition): object to commit changes
 
@@ -365,10 +361,9 @@ class GitRepo(object):
         self.messages = []
 
     def is_dirty(self, filename):
-        """
-        Returns True if filename needs to be committed to git 
+        """ Returns True if filename needs to be committed to git
 
-        Arguments: 
+        Args:
 
             filename (str): file to check
         """
@@ -378,16 +373,14 @@ class GitRepo(object):
         return len(output) > 0
 
     def write(self, object_definition, message):
-        """
-        This method is called whenever :py:class:`pynag.Model.EventHandlers`
+        """ This method is called whenever :py:class:`pynag.Model.EventHandlers`
         is called.
 
-        Arguments
+        Args:
 
             object_definition (pynag.Model.ObjectDefinition): Object to write to file.
 
             message (str): git commit message as specified in  ``git commit -m``
-
         """
         # When write is called ( something was written to file )
         # We will log it in a buffer, and commit when save() is called.
@@ -402,17 +395,17 @@ class GitRepo(object):
     def commit(self, message='commited by pynag', filelist=None, author=None):
         """ Commit files with "git commit"
 
-        Arguments:
+        Args:
 
             message (str): Message used for the git commit
 
-            filelist (list of strings): List of filenames to commit (if None, 
-                then commit all files in the repo)
-            author (str): Author to use for git commit. If any is specified, 
-                overwrite self.author_name and self.author_email
+            filelist (list of strings): List of filenames to commit (if None,
+            then commit all files in the repo)
+
+            author (str): Author to use for git commit. If any is specified,
+            overwrite self.author_name and self.author_email
 
         Returns:
-
             stdout from the "git commit" shell command.
 
         """
@@ -460,17 +453,17 @@ class GitRepo(object):
             return
         # Create a space seperated string with the filenames
         filestring = ' '.join(filelist)
-        command = "git commit -m '%s' --author='%s' -- %s" % (message, author,filestring)
+        command = "git commit -m '%s' --author='%s' -- %s" % (message, author, filestring)
         return self._run_command(command=command)
 
     def add(self, filename):
         """ Run git add on filename
 
-            Arguments:
-                filename (str): name of one file to add,
+        Args:
+            filename (str): name of one file to add,
 
-            Returns:
-                str. The stdout from "git add" shell command.
+        Returns:
+            str. The stdout from "git add" shell command.
         """
 
         # Escape all single quotes in filename:
@@ -498,7 +491,7 @@ class PerfData(object):
 
     def __init__(self, perfdatastring=""):
         """
-        >>> perf = PerfData("load1=10 load2=10 load3=20") 
+        >>> perf = PerfData("load1=10 load2=10 load3=20")
         """
         self.metrics = []
         self.invalid_metrics = []
@@ -537,10 +530,9 @@ class PerfData(object):
         return True
 
     def add_perfdatametric(self, perfdatastring="", label="", value="", warn="", crit="", min="", max="", uom=""):
-        """ 
-        Add a new perfdatametric to existing list of metrics.
+        """ Add a new perfdatametric to existing list of metrics.
 
-        Arguments:
+        Args:
 
             perfdatastring (str): Complete perfdata string
 
@@ -564,13 +556,13 @@ class PerfData(object):
         >>> s.add_perfdatametric("a=1")
         >>> s.add_perfdatametric(label="utilization",value="10",uom="%")
         """
-        metric=PerfDataMetric(perfdatastring=perfdatastring, label=label,value=value,warn=warn,crit=crit,min=min,max=max,uom=uom)
+        metric = PerfDataMetric(perfdatastring=perfdatastring, label=label, value=value, warn=warn, crit=crit, min=min, max=max, uom=uom)
         self.metrics.append(metric)
 
     def get_perfdatametric(self, metric_name):
         """ Get one specific perfdatametric
 
-        Arguments:
+        Args:
             metric_name (str): Name of the metric to return
 
         Example:
@@ -596,9 +588,8 @@ class PerfData(object):
 
 class PerfDataMetric(object):
 
-    """
-    Data structure for one single Nagios Perfdata Metric 
-    
+    """ Data structure for one single Nagios Perfdata Metric
+
 
     Attributes:
 
@@ -620,13 +611,13 @@ class PerfDataMetric(object):
 
     """
 
-    label = "" #: str. Label section of the perfdata string
-    value = "" #: str. Value section of the perfdata string
-    warn = "" #: str. WARNING threshold
-    crit = "" #: str CRITICAL threshold
-    min = "" #: str. Minimal value of control
-    max = "" #: str. Maximal value of control
-    uom = "" #: str. Measure unit (octets, bits/s, volts, ...)
+    label = ""  # : str. Label section of the perfdata string
+    value = ""  # : str. Value section of the perfdata string
+    warn = ""  # : str. WARNING threshold
+    crit = ""  # : str CRITICAL threshold
+    min = ""  # : str. Minimal value of control
+    max = ""  # : str. Maximal value of control
+    uom = ""  # : str. Measure unit (octets, bits/s, volts, ...)
 
     def __repr__(self):
         return "'%s'=%s%s;%s;%s;%s;%s" % (
@@ -710,10 +701,9 @@ class PerfDataMetric(object):
             self.max = tmp.pop(0)
 
     def get_status(self):
-        """ 
-        Return nagios-style exit code (int 0-3) by comparing
+        """ Return nagios-style exit code (int 0-3) by comparing
 
-        Example: 
+        Example:
 
         self.value with self.warn and self.crit
 
@@ -738,8 +728,7 @@ class PerfDataMetric(object):
         return status
 
     def is_valid(self):
-        """ 
-        Returns True if all Performance data is valid. Otherwise False
+        """ Returns True if all Performance data is valid. Otherwise False
 
         Example Usage:
 
@@ -789,15 +778,16 @@ class PerfDataMetric(object):
         return True
 
     def reconsile_thresholds(self):
-        """ 
-        Convert threshold from new threshold syntax to current one, for backwards compatibility 
+        """ Convert threshold from new threshold syntax to current one.
+
+        For backwards compatibility
         """
 
         self.warn = reconsile_threshold(self.warn)
         self.crit = reconsile_threshold(self.crit)
 
     def split_value_and_uom(self, value):
-        """ 
+        """
         Example:
 
         get value="10M" and return (10,"M")
@@ -830,8 +820,7 @@ class PerfDataMetric(object):
         return tmp[0]
 
     def get_dict(self):
-        """
-        Returns a dictionary which contains this class' attributes.
+        """ Returns a dictionary which contains this class' attributes.
 
         Returned dict example::
 
@@ -856,12 +845,11 @@ class PerfDataMetric(object):
             'max': self.max,
         }
 
+
 def grep(objects, **kwargs):
+    """ Returns all the elements from array that match the keywords in **kwargs
 
-    """
-    Returns all the elements from array that match the keywords in **kwargs
-
-    See documentation for pynag.Model.ObjectDefinition.objects.filter() for 
+    See documentation for pynag.Model.ObjectDefinition.objects.filter() for
     example how to use this.
 
     Arguments:
@@ -888,7 +876,7 @@ def grep(objects, **kwargs):
     search = []
     for k, v in kwargs.items():
         # We need the actual array in "v" for __in and __notin
-        if type(v) == type([]) and not (k.endswith('__in') or k.endswith('__notin')):
+        if isinstance(v, type([])) and not (k.endswith('__in') or k.endswith('__notin')):
             for i in v:
                 search.append((k, i))
         else:
@@ -917,7 +905,7 @@ def grep(objects, **kwargs):
             expression = lambda x: not str(x.get(k)).endswith(v_str)
         elif k.endswith('__exists'):
             k = k[:-len('__exists')]
-            expression = lambda x: str(x.has_key(k)) == v_str
+            expression = lambda x: str(k in x) == v_str
         elif k.endswith('__isnot'):
             k = k[:-len('__isnot')]
             expression = lambda x: v_str != str(x.get(k))
@@ -942,15 +930,13 @@ def grep(objects, **kwargs):
         else:
             # If all else fails, assume they are asking for exact match
             v_is_str = isinstance(v, str)
-            expression = lambda obj: (lambda objval: str(objval) == v_str or ( v_is_str and isinstance(objval, list) and v in objval ) ) (obj.get(k))
+            expression = lambda obj: (lambda objval: str(objval) == v_str or (v_is_str and isinstance(objval, list) and v in objval))(obj.get(k))
         matching_objects = filter(expression, matching_objects)
     return matching_objects
 
 
 def grep_to_livestatus(*args, **kwargs):
-
-    """ 
-    Converts from pynag style grep syntax to livestatus filter syntax.
+    """ Converts from pynag style grep syntax to livestatus filter syntax.
 
     Example:
 
@@ -1011,11 +997,10 @@ def grep_to_livestatus(*args, **kwargs):
 
 class AttributeList(object):
 
-    """ 
-    Parse a list of nagios attributes (e. contact_groups) into a parsable 
-    format.
+    """ Parse a list of nagios attributes into a parsable format.
+    (e. contact_groups)
 
-    This makes it handy to mangle with nagios attribute values that are in a 
+    This makes it handy to mangle with nagios attribute values that are in a
     comma seperated format.
 
     Typical comma-seperated format in nagios configuration files looks something
@@ -1086,9 +1071,11 @@ class AttributeList(object):
         """  Same as list.insert()
 
         Args:
+
             object: Any object that will be inserted into self.fields (usually a string)
 
-        Example:
+        Example::
+
             >>> i = AttributeList('group1,group2,group3')
             >>> i.insert(1, 'group4')
             >>> i.fields
@@ -1101,9 +1088,12 @@ class AttributeList(object):
         """ Same as list.append():
 
         Args:
+
             object: Item to append into self.fields (typically a string)
 
+
         Example:
+
             >>> i = AttributeList('group1,group2,group3')
             >>> i.append('group5')
             >>> i.fields
@@ -1147,7 +1137,9 @@ class AttributeList(object):
 
         Args:
             value:  object to look for in self.fields
+
             start:  start at this index point
+
             stop:   stop at this index point
 
         Returns:
@@ -1205,8 +1197,7 @@ class AttributeList(object):
         return self.fields.remove(value)
 
     def __iter__(self):
-        """ 
-        Same as list.__iter__()
+        """ Same as list.__iter__()
 
         >>> mylist = AttributeList('group1,group2,group3')
         >>> for i in mylist: print(i)
@@ -1251,10 +1242,10 @@ class PluginOutput:
     ['load1'=15;;;;, 'load2'=10;;;;]
 
     """
-    summary = None #: str. Summary returned by the plugin check
+    summary = None  # : str. Summary returned by the plugin check
     long_output = None
-    perfdata = None #: str. Data returned by the plugin as a string
-    parsed_perfdata = None #: Perfdata parsed and split
+    perfdata = None  # : str. Data returned by the plugin as a string
+    parsed_perfdata = None  # : Perfdata parsed and split
 
     def __init__(self, stdout):
         if not stdout:
@@ -1279,10 +1270,10 @@ class PluginOutput:
         self.perfdata = perfdata.strip()
         self.parsed_perfdata = PerfData(perfdatastring=perfdata)
 
+
 class defaultdict(dict):
 
-    """ 
-    This is an alternative implementation of collections.defaultdict.
+    """ This is an alternative implementation of collections.defaultdict.
 
     Used as a fallback if using python 2.4 or older.
 
@@ -1295,8 +1286,7 @@ class defaultdict(dict):
     """
 
     def __init__(self, default_factory=None, *a, **kw):
-        if (default_factory is not None and
-            not hasattr(default_factory, '__call__')):
+        if (default_factory is not None and not hasattr(default_factory, '__call__')):
             raise TypeError('first argument must be callable')
         dict.__init__(self, *a, **kw)
         self.default_factory = default_factory
@@ -1336,14 +1326,13 @@ class defaultdict(dict):
 
 
 def reconsile_threshold(threshold_range):
-    """ 
-    Take threshold string as and normalize it to the format supported by plugin 
+    """ Take threshold string as and normalize it to the format supported by plugin
     development team
 
-    The input (usually a string in the form of 'the new threshold syntax') is a 
+    The input (usually a string in the form of 'the new threshold syntax') is a
     string in the form of x..y
 
-    The output will be a compatible string in the older nagios plugin format 
+    The output will be a compatible string in the older nagios plugin format
     @x:y
 
     Examples:
@@ -1394,8 +1383,7 @@ def reconsile_threshold(threshold_range):
 
 
 def synchronized(lock):
-    """ 
-    Synchronization decorator
+    """ Synchronization decorator
 
     Use this to make a multi-threaded method synchronized and thread-safe.
 
@@ -1418,37 +1406,34 @@ def synchronized(lock):
 
 def cache_only(func):
     def wrap(*args, **kwargs):
-        print "aggressive caching on"
         pynag.Model.ObjectFetcher._cache_only = True
         try:
             return func(*args, **kwargs)
         finally:
             pynag.Model.ObjectFetcher._cache_only = False
-            print "Aggressive caching off"
     wrap.__name__ = func.__name__
     wrap.__module__ = func.__module__
     return wrap
 
 
 def send_nsca(code, message, nscahost, hostname=None, service=None, nscabin="send_nsca", nscaconf=None):
-    """ 
-    Send data via send_nsca for passive service checks
+    """ Send data via send_nsca for passive service checks
 
-    Arguments:
+    Args:
 
         code (int): Return code of plugin.
 
         message (str): Message to pass back.
 
         nscahost (str): Hostname or IP address of NSCA server.
-        
+
         hostname (str): Hostname the check results apply to.
-        
+
         service (str): Service the check results apply to.
-        
+
         nscabin (str): Location of send_nsca binary. If none specified whatever
-                       is in the path will be used.
-        
+        is in the path will be used.
+
         nscaconf (str): Location of the NSCA configuration to use if any.
 
     Returns:
