@@ -16,6 +16,7 @@ from pynag.Utils import PynagError
 
 
 class FakeNagiosEnvironment(object):
+
     """ Creates a fake nagios environment with minimal configs in /tmp/
 
     Example:
@@ -29,14 +30,19 @@ class FakeNagiosEnvironment(object):
         >>> result, stdout, sdterr = nagios.stop()  # Stop nagios
         >>> nagios.terminate()  # Stops nagios and cleans up everything
     """
+
     def __init__(self, global_config_file=None, p1_file=None, livestatus=False):
         self.global_config_file = global_config_file
         self.p1_file = p1_file
         self._model_is_dirty = False
-        self.livestatus_path = livestatus
+        self.livestatus_module_path = livestatus
         self.livestatus_object = None
         self.config = None
 
+        self.tempdir = tempfile.mkdtemp('nagios-environment')
+        path_to_socket = os.path.join(self.tempdir, "livestatus.socket")
+        self.livestatus_socket_path = path_to_socket
+
     def get_config(self):
         if not self.config:
             self.create_minimal_environment()
@@ -84,30 +90,57 @@ class FakeNagiosEnvironment(object):
 
     def create_minimal_environment(self):
         """ Starts a nagios server with empty config in an isolated environment """
-        self.tempdir = t = tempfile.mkdtemp('nagios-environment') + "/"
-        cfg_file = self.cfg_file = t + "/nagios.cfg"
+        t = self.tempdir
+        cfg_file = self.cfg_file = os.path.join(t, "nagios.cfg")
         open(cfg_file, 'w').write('')
 
-        objects_dir = self.objects_dir = t + "/conf.d"
+        objects_dir = self.objects_dir = os.path.join(t, "conf.d")
         os.mkdir(objects_dir)
 
+        check_result_path = os.path.join(self.tempdir, 'checkresults')
+        os.mkdir(check_result_path)
+
+        log_dir = os.path.join(self.tempdir, 'log')
+        archive_dir = os.path.join(log_dir, 'archive')
+        os.mkdir(log_dir)
+        os.mkdir(archive_dir)
+
         with open(objects_dir + "/minimal_config.cfg", 'w') as f:
             f.write(minimal_config)
 
         config = self.config = pynag.Parsers.config(cfg_file=cfg_file)
         self.config.open = self.open_decorator(self.config.open)
         config.parse()
-        config._edit_static_file(attribute='log_file', new_value=t + "/nagios.log")
-        config._edit_static_file(attribute='object_cache_file', new_value=t + "objects.cache")
-        config._edit_static_file(attribute='precached_object_file', new_value=t + "/objects.precache")
-        config._edit_static_file(attribute='lock_file', new_value=t + "nagios.pid")
-        config._edit_static_file(attribute='command_file', new_value=t + "nagios.cmd")
-        config._edit_static_file(attribute='state_retention_file', new_value=t + "retention.dat")
+        config._edit_static_file(attribute='log_archive_path',
+                                 new_value=os.path.join(t, "log/archive"))
+        config._edit_static_file(attribute='log_file',
+                                 new_value=os.path.join(t, "log/nagios.log"))
+        config._edit_static_file(attribute='object_cache_file',
+                                 new_value=os.path.join(t, "objects.cache"))
+        config._edit_static_file(attribute='precached_object_file',
+                                 new_value=os.path.join(t, "/objects.precache"))
+        config._edit_static_file(attribute='lock_file',
+                                 new_value=os.path.join(t, "nagios.pid"))
+        config._edit_static_file(attribute='command_file',
+                                 new_value=os.path.join(t, "nagios.cmd"))
+        config._edit_static_file(attribute='state_retention_file',
+                                 new_value=os.path.join(t, "retention.dat"))
+        config._edit_static_file(attribute='status_file',
+                                 new_value=os.path.join(t, "status.dat"))
         config._edit_static_file(attribute='cfg_dir', new_value=objects_dir)
-        config._edit_static_file(attribute='log_initial_states', new_value="1")
-        config._edit_static_file(attribute='enable_embedded_perl', new_value='0')
-        config._edit_static_file(attribute='event_broker_options', new_value='-1')
-        config._edit_static_file(attribute='illegal_macro_output_chars', new_value='''~$&|<>''')
+        config._edit_static_file(attribute='log_initial_states',
+                                 new_value="1")
+        config._edit_static_file(attribute='enable_embedded_perl',
+                                 new_value='0')
+        config._edit_static_file(attribute='event_broker_options',
+                                 new_value='-1')
+        config._edit_static_file(attribute='illegal_macro_output_chars',
+                                 new_value='''~$&|<>''')
+        config._edit_static_file(attribute='check_result_path',
+                                 new_value=check_result_path)
+        config._edit_static_file(attribute='temp_path', new_value=log_dir)
+        config._edit_static_file(attribute='temp_file',
+                                 new_value=os.path.join(t, "nagios.tmp"))
 
     def clean_up(self):
         """ Clean up all temporary directories """
@@ -121,19 +154,31 @@ class FakeNagiosEnvironment(object):
             self.restore_model()
         self.clean_up()
 
-    def start(self, start_command=None):
+    def start(self, start_command=None, timeout=10):
         self.configure_p1_file()
         if not start_command:
             nagios_binary = self.config.guess_nagios_binary()
             start_command = "%s -d %s" % (nagios_binary, self.config.cfg_file)
         result = pynag.Utils.runCommand(command=start_command)
         code, stdout, stderr = result
+
+        pid_file = os.path.join(self.tempdir, "nagios.pid")
+        while not os.path.exists(pid_file) and timeout:
+            timeout -= 1
+            time.sleep(1)
+
+        start_error = None
+        if not os.path.exists(pid_file):
+            start_error = "Nagios pid file did not materialize"
         if result[0] != 0:
-            if os.path.exists(self.tempdir + "nagios.log"):
-                log_file_output = open(self.tempdir + "nagios.log").read()
+            start_error = "Nagios did not start, bad return code"
+
+        if start_error:
+            if os.path.exists(os.path.join(self.tempdir, "nagios.log")):
+                log_file_output = open(os.path.join(self.tempdir, "nagios.log")).read()
             else:
                 log_file_output = "No log file found."
-            message = "Failed to start Nagios."
+            message = start_error
             message += "Command: {start_command}\n"
             message += "Exit Code: {code}\n"
             message += "============\nStandard out\n{stdout}\n"
@@ -144,7 +189,7 @@ class FakeNagiosEnvironment(object):
         return result
 
     def stop(self, stop_command=None):
-        pid_file = self.tempdir + "nagios.pid"
+        pid_file = os.path.join(self.tempdir, "nagios.pid")
         if not os.path.exists(pid_file):
             return
         pid = open(pid_file).read()
@@ -156,10 +201,9 @@ class FakeNagiosEnvironment(object):
         return result
 
     def configure_livestatus(self):
-        if not self.livestatus_path:
-            self.livestatus_path = self.guess_livestatus_path()
-        path_to_socket = self.tempdir + "/livestatus.socket"
-        line = "%s %s" % (self.livestatus_path, path_to_socket)
+        if not self.livestatus_module_path:
+            self.livestatus_module_path = self.guess_livestatus_path()
+        line = "%s %s" % (self.livestatus_module_path, self.livestatus_socket_path)
         config = self.get_config()
         config._edit_static_file(attribute="broker_module", new_value=line)
         self.livestatus_object = pynag.Parsers.Livestatus(
@@ -193,6 +237,20 @@ class FakeNagiosEnvironment(object):
                 livestatus_module = v.split()[0]
                 return livestatus_module
 
+    def import_config(self, path):
+        """ Copies any file or directory into our environment and include it in object configuration
+
+        Args:
+            path:   full path to a nagios cfg file or a directory of cfg files
+
+        Raises:
+            Exception if path is not found
+        """
+        destination = self.objects_dir
+        command = "cp -r '{path}' '{destination}/'".format(**locals())
+        return os.system(command)
+
+
 minimal_config = r"""
     define timeperiod {
       alias                          24 Hours A Day, 7 Days A Week
